<?php

function tagged_output ($output, $tag, $css_class = "") {
	if (!empty($output)) {
		if (!empty($tag)) {
			echo '<' . $tag;
			if (!empty($css_class))
				echo ' class="' . $css_class . '"';
			echo '>';
		}
		echo $output;
		if (!empty($tag))
			echo '</' . $tag . '>';
	}
}

function the_main_topic_and_audience( $post, $linked = true ) {
	$main_audience = get_main_audience($post);
	if ($main_audience)
		$main_audience_name = $main_audience->name;
	else
		$main_audience_name = GEMEIMDE_APP_DEFAULT_AUDIENCE_NAME;
	tagged_output('<span class="meta-info main-audience">'. $main_audience_name . '</span>', 'div');

	$main_topic = get_main_topic( $post);
	if ($main_topic)
		tagged_output('<span class="meta-info main-topic">'. $main_topic->name . '</span>',  'div');
}

function the_main_topic_svg($post) {
		$svg = get_main_topic_svg($post);
		if ( strlen( $svg ) > 0 ) {echo $svg;}
}

function the_main_audience_color_style($post) {
	$color = get_main_audience_color($post);
	if ( strlen( $color ) == 0 ) {
		$color = GEMEIMDE_APP_DEFAULT_AUDIENCE_COLOR;
	}
	echo 'style="--audience-color:'. $color .'"';
}

function get_main_topic($post)    {return get_main_term($post, 'main_topics');}
function get_main_audience($post) {return get_main_term($post, 'main_audiences');}

function get_main_audience_color($post) {return get_main_meta(get_main_audience($post), 'color');}
function get_main_topic_svg($post)      {return get_main_meta(get_main_topic($post),    'svg_icon');}

function get_main_term($post, $taxonomy) {
	$terms = get_the_terms( $post->id, $taxonomy );
	if ( is_wp_error( $terms ) ) { return false; }
	if ( empty( $terms ) ) { return false; }
	return $terms[0];
}

function get_main_meta($term, $attribute) {
	if (!$term) {return '';}
	return get_term_meta( $term->term_id, $attribute, true );
}

function the_contact_person($post, $with_date = true, $tag = "div") {
	$output = array();
	if (! "" == get_contact_person($post))
		$output[]= get_contact_person($post);
	if ($with_date)
		$output[]= get_the_date();
	tagged_output(implode(", ", $output), $tag, "contact-person");
}

function get_contact_person($post) { return get_post_meta( $post->ID, 'contact_person', true); }

function get_deep_link($post) {return get_post_meta( $post->ID, 'app_url', true); }

// Render main_image with copyright
function get_the_post_main_image(int $post_id, $attr = '') {
	$main_image_url = get_post_meta( $post_id, 'main_image_url', true);
	$html  = '';
	if (!empty($main_image_url)) {
		$default_attr = array( 'src' => esc_url($main_image_url), 'loading' => 'lazy' );
		$attr = wp_parse_args( $attr, $default_attr );
		$attr = array_map( 'esc_attr', $attr );
		$html = "<img";
		foreach ( $attr as $name => $value ) {
				$html .= " $name=" . '"' . $value . '"';
		}
		$html .= ' />';
		$main_image_copyright = get_post_meta( $post_id, 'main_image_copyright', true);
		if (!empty($main_image_copyright)) {
			$html .= '<span class="copyright-info">' . esc_html($main_image_copyright) . '</span>';
		}
	}
	return $html;
}

function the_post_main_image($post) { echo get_the_post_main_image($post -> ID);}
function the_post_type($post) { echo get_post_meta( $post -> ID, 'post_type', true);}

function the_event($post, $linked = true) {
	$event_id = get_field("event", $post->ID);
	if (!empty($event_id)) {
		$event = get_post($event_id);
		if (is_object( $event )) {
			$title = get_the_title($event);
			if ( strlen( $title ) == 0 ) { $title = "Ein Termin"; }
			$title = esc_attr( strip_tags( $title ) );
			$html = '';
			if ($linked) {
				$html = 'Zum Termin: <a href="' . get_permalink($event) .'" title="' . $title . '">' . $title . '</a>' ;
			} else {
				$html = 'Zum Termin: ' . $title  ;
			}
			tagged_output($html, 'div');
		}
	}
}

function the_group($post, $linked = true) {
	$group_id = get_field("group", $post->ID);
	if (!empty($group_id)) {
		$group = get_post($group_id);
		if (is_object( $group )) {
			$title = get_the_title($group);
			if ( strlen( $title ) == 0 ) { $title = "Eine Gemeindegruppe"; }
			$title = esc_attr( strip_tags( $title ) );
			$html = '';
			if ($linked) {
				$html = 'Aus der Gruppe: <a href="' . get_permalink($group) .'" title="' . $title . '">' . $title . '</a>' ;
			} else {
				$html = 'Aus der Gruppe: ' . $title . '' ;
			}
			tagged_output($html, 'div');
		}
	}
}

# require_once( get_template_directory() . '/includes/custom-menu-items.php' );

/*
add_filter( 'wp_nav_menu_objects', 'add_topics_nav_menu_items', 10, 2 );

function _custom_nav_menu_item( $title, $url, $order, $parent = 0 ){
	$item = new stdClass();
	$item->ID = 1000000 + $order + $parent;
	$item->db_id = $item->ID;
	$item->title = $title;
	$item->url = $url;
	$item->menu_order = $order;
	$item->menu_item_parent = $parent;
	$item->type = '';
	$item->object = '';
	$item->object_id = '';
	$item->classes = array();
	$item->target = '';
	$item->attr_title = '';
	$item->description = '';
	$item->xfn = '';
	$item->status = '';
	$item->current = '';
	return $item;
}

function add_topics_nav_menu_items( $items, $menu ){
	if( $menu -> theme_location =="primary" ) {
		//parent menu item
		$parent_item = _custom_nav_menu_item('Themen','',5, 247);
		$items[] = (object) $parent_item;
		$terms = get_terms(array('taxonomy' => 'main_topics', 'hide_empty' => true));

		// Check if any term exists
		if ( ! empty( $terms ) && is_array( $terms ) ) {
				// Run a loop and print them all
				foreach ( $terms as $key=>$term ) {
					$items[] = _custom_nav_menu_item($term->name,get_term_link( $term ),$key, $parent_item -> ID);
				}
		}
	}
	return $items;
}
*/
