<?php
/**
 * Register custom query vars
 * @param array $vars The array of available query variables
 * @link https://codex.wordpress.org/Plugin_API/Filter_Reference/query_vars
 */
add_filter( 'query_vars', function ( $vars ) {
	foreach (GEMEINDE_APP_TAXONOMIES as $taxonomy => $tax_defs) {
		$vars[] = $tax_defs['singular'];
	}
	return $vars;
});

/**
 * Build a custom query. Regarding sanitization: https://wordpress.stackexchange.com/a/149229
 * @param $query obj The WP_Query instance (passed by reference)
 * @link https://codex.wordpress.org/Plugin_API/Action_Reference/pre_get_posts
 */
add_action( 'pre_get_posts', function($query){
	// check if the user is requesting an admin page or current query is not the main query
	if (!is_post_type_archive( GEMEINDE_APP_TYPES ) || is_admin() || ! $query->is_main_query() ){ return; }

	$tax_query = array();
	foreach (GEMEINDE_APP_TAXONOMIES as $taxonomy => $tax_defs) {
		$tax_singular = $tax_defs['singular'];
		if( !empty( get_query_var( $tax_singular ) ) ){
			$tax_query[] = array('taxonomy' => $taxonomy, 'field' => 'slug', 'terms' => get_query_var($tax_singular));
		}
	}

	if( count( $tax_query ) > 1 ){ $tax_query['relation'] = 'AND'; }
	if( count( $tax_query ) > 0 ){ $query->set( 'tax_query', $tax_query ); }
}, 12 );

// Groups are ordered by title
add_action( 'pre_get_posts', function($query){
	if (!is_post_type_archive( 'group' ) || ! $query->is_main_query() ){ return; }
	$query->set( 'order', 'ASC' );
  $query->set( 'orderby', 'title' );
}, 12 );

/**
* - Filter-URLs für Aushänge, Gruppen und Termine:
*		- /thema/gottesdienst/aushaenge
*		- /zielgruppe/erwachsene/termine
*/
add_action('init', function(){
	foreach (GEMEINDE_APP_TAXONOMIES as $taxonomy => $tax_defs) {
		add_rewrite_tag( '%'. $tax_defs['singular'] . '%', '([^&]+)' );
		foreach (GEMEINDE_APP_TYPE_SLUGS as $type => $type_slug) {
			add_rewrite_rule( $tax_defs['filter_slug'] . '/([^/]+)/' . $type_slug . '/?$', 'index.php?post_type=' . $type . '&' . $tax_defs['singular'] . '=$matches[1]','top' );
		}
	}
}, 10, 0);
