<?php
/**
 * Locate the called template.
 * Search Order:
 * 1.  theme/$template-$post_type in theme (found by locate_template())
 * 2. plugin/$template-$post_type in this plugin (file in /plugins/die-gemeinde-app/templates)
 * 1.  theme/$template            in theme (found by locate_template())
 * 2. plugin/$template            in this plugin (file in /plugins/die-gemeinde-app/templates)
 *
 * @since 1.0.0
 *
 * @param string  $template          Template to load.
 * @param string  $post_type         Post type.
 * @return string                    Path to the template file.
 */
function gemeinde_app_locate_template( $template, $post_type="") {
  $template_file_name_with_type = $template . '-' . $post_type . '.php';
  $template_file_name           = $template .                    '.php';
  error_log("CHECK " . GEMEINDE_APP_TEMPLATES_DIR . $template_file_name_with_type);
  error_log("CHECK " . GEMEINDE_APP_TEMPLATES_DIR . $template_file_name);

  $located = '';

  if ((!empty($post_type)) && locate_template( $template_file_name_with_type )) {
    $located = locate_template( $template_file_name_with_type );
  } elseif ((!empty($post_type)) && file_exists( GEMEINDE_APP_TEMPLATES_DIR . $template_file_name_with_type )) {
    $located = GEMEINDE_APP_TEMPLATES_DIR . $template_file_name_with_type ;
  } elseif (locate_template( $template_file_name )) {
    $located = locate_template( $template_file_name );
  } else {
    $located = GEMEINDE_APP_TEMPLATES_DIR . $template_file_name;
  }

  return apply_filters( 'gemeinde_app_locate_template', $located, $post_type, $template);
}

/**
 * Get template part. Helper function
 *
 * Search for the template and include the file.
 *
 * @since 1.0.0
 *
 * @see gemeinde_app_locate_template()
 *
 * @param string  $template          Template to load.
 * @param string  $post_type         Post type.
 * @param array   $args              Args passed for the template file.
 */
function get_gemeinde_app_template_part( $template, $post_type, $args = array()) {
  $located = gemeinde_app_locate_template( $template, $post_type);

  if ('' !== $located ) {
    load_template( $located, false, $args );
  } else {
    return false;
  }
}

/**
 * Template loader.
 *
 * The template loader will check if WP is loading a template
 * for a specific Post Type and will try to load the template
 * from out 'templates' directory.
 *
 * @since 1.0.0
 *
 * @param string  $template Template file that is being loaded.
 * @return  string          Template file that should be loaded.
 */
function gemeinde_app_template_loader( $template ) {
  error_log( "[gemeinde_app_template_loader] ". $template );
  if (is_post_type_archive(GEMEINDE_APP_TYPES) || is_singular(GEMEINDE_APP_TYPES)) {
    error_log( "[gemeinde_app_template_loader] ". 'PostType is ' . get_post_type());
    $gemeinde_app_template_file = '';

    if( is_singular(GEMEINDE_APP_TYPES) ) {
      error_log( "[gemeinde_app_template_loader] ". 'SINGULAR' );
      $gemeinde_app_template_file = gemeinde_app_locate_template('gemeinde-app-single', get_post_type());
    }
    elseif( is_post_type_archive(GEMEINDE_APP_TYPES) ) {
      error_log( "[gemeinde_app_template_loader] ". 'ARCHIVE' );
      $gemeinde_app_template_file = gemeinde_app_locate_template('gemeinde-app-archive', get_post_type());
    }

    if ( file_exists( $gemeinde_app_template_file ) ) {$template = $gemeinde_app_template_file;}
    error_log( "[gemeinde_app_template_loader] ". $gemeinde_app_template_file . ' => ' . $template );

  }

  return $template;
}

add_filter( 'template_include', 'gemeinde_app_template_loader' );

function gemeinde_app_register_style( $handle, $src, $deps = array(), $ver = false, $media = 'all' ) {
	$src = apply_filters( 'gemeinde_app_stylesheet_src', $src, $handle );
	$src = apply_filters( 'gemeinde_app_stylesheet_src_' . $handle, $src );
  error_log( "[gemeinde_app_register_style] ". $handle . " from " . $src );
	return wp_register_style( $handle, $src, $deps, $ver, $media );
}

add_action('init', function(){
  /* Styles */
  gemeinde_app_register_style('gemeinde_app-styles', GEMEINDE_APP_URL . "assets/css/die-gemeinde-app.css", array(), GEMEINDE_APP_VERSION );
	gemeinde_app_register_style('gemeinde_app-content-styles', GEMEINDE_APP_URL . "assets/css/gemeinde-app-content.css", array(), GEMEINDE_APP_VERSION );
});

// use the registered jquery and style above
add_action('wp_enqueue_scripts', function() {
  wp_enqueue_style( 'gemeinde_app-styles' );
	wp_enqueue_style( 'gemeinde_app-content-styles' );
});

add_filter('get_the_excerpt', function($in, $post) {
#	error_log("[get_the_excerpt] ".($post -> post_type) . ($post -> ID). "GemeindeApp-Type? ". (in_array($post -> post_type, GEMEINDE_APP_TYPES)) .": " . wp_filter_nohtml_kses(get_the_content()));
	if (in_array($post -> post_type, GEMEINDE_APP_TYPES)) {
	  # error_log("[get_the_excerpt] ".($post -> post_type) . ($post -> ID) .": " . get_the_content());
	  # error_log("[get_the_excerpt] ".($post -> post_type) . ($post -> ID) .": " . wp_kses(get_the_content(), 'strip'));
		return wp_trim_words(wp_kses(get_the_content(), 'strip'), 20, ' &hellip;');
	} else {
		return $in;
	}
}, 9, 2);
